@@ -35,25 +35,33 @@ waldtest <- function(N,nfact,place,modality,b,Varb,Lfirts=NULL,Llast=NULL,Ntot=N
 			if(!is.null(Lfirts)) L <- cbind(matrix(0,nrow=modality[i],ncol=Lfirts),L)
 			if(!is.null(Llast)) L <- cbind(L,matrix(0,nrow=modality[i],ncol=Llast))
 		}
-		# W <- 0
-		# r = dim(L)[1]
-		# save(L, file='L.RData')
-		# save(Varb, file='Varb.RData')
-		# W = t(L%*%b) %*% solve(L%*%Varb%*%t(L)) %*% (L%*%b)
-		# W = as.numeric(W)
-		# waldValue[i] = W 
+		W <- 0
+		r = dim(L)[1]
+		W = t(L%*%b) %*% solve(L%*%Varb%*%t(L)) %*% (L%*%b)
+		# W = t(L%*%b) %*% (L%*%(Varb%*%t(L))) %*% (L%*%b)
+		W = as.numeric(W)
+		waldValue[i] = W 
 		
-		if(is.null(Ntot))Ntot <- N
-		out <- .Fortran("waldmultiv",
-				as.double(b),
-				as.integer(Ntot),
-				as.integer(L),
-				as.double(Varb),
-				as.integer(modality[i]),
-				Wald=as.double(0),
-				PACKAGE = "frailtypack")
-		 waldValue[i] <- out$Wald
-	#		print(L)
+		# cat('en R \n : b')
+		# print(b)
+		# cat('L')
+		# print(L)
+		# cat('Varb')
+		# print(Varb)
+		
+		# cat('En fortran\n')
+		
+		# if(is.null(Ntot))Ntot <- N
+		# out <- .Fortran("waldmultiv",
+				# as.double(b),
+				# as.integer(Ntot),
+				# as.integer(L),
+				# as.double(Varb),
+				# as.integer(modality[i]),
+				# Wald=as.double(0),
+				# PACKAGE = "frailtypack")
+		 # waldValue[i] <- out$Wald
+	# #		print(L)
 	}
 	return(waldValue)
 }# end Wald
